@@ -4,18 +4,17 @@
 # See top-level LICENSE file for more information
 
 from swh.scanner.db import Db
+from swh.scanner.policy import QUERY_LIMIT
 
 from .data import present_swhids
 
-CHUNK_SIZE = 1000
-
 
 def test_db_create_from(tmp_path, test_swhids_sample):
     tmp_dbfile = tmp_path / "tmp_db.sqlite"
 
     db = Db(tmp_dbfile)
     cur = db.conn.cursor()
-    db.create_from(test_swhids_sample, CHUNK_SIZE, cur)
+    db.create_from(test_swhids_sample, QUERY_LIMIT, cur)
 
     for swhid in present_swhids:
         cur = db.conn.cursor()
@@ -30,7 +29,7 @@ def test_db_create_from_one_not_present(tmp_path, test_swhids_sample):
 
     db = Db(tmp_dbfile)
     cur = db.conn.cursor()
-    db.create_from(test_swhids_sample, CHUNK_SIZE, cur)
+    db.create_from(test_swhids_sample, QUERY_LIMIT, cur)
 
     for swhid in swhids:
         cur = db.conn.cursor()
